@@ -10,16 +10,16 @@
 #
 
 import os
+from netrc import netrc
 from typing import Dict
 from typing import List
 from typing import NamedTuple
 from typing import Sequence
 
 from packageurl import PackageURL
-from packaging.requirements import Requirement
+from packvers.requirements import Requirement
 from resolvelib import BaseReporter
 from resolvelib import Resolver
-from tinynetrc import Netrc
 
 from _packagedcode.models import DependentPackage
 from _packagedcode.models import PackageData
@@ -38,8 +38,10 @@ from python_inspector.resolution import get_environment_marker_from_environment
 from python_inspector.resolution import get_package_list
 from python_inspector.resolution import get_python_version_from_env_tag
 from python_inspector.resolution import get_requirements_from_python_manifest
+from python_inspector.utils_pypi import PLATFORMS_BY_OS
 from python_inspector.utils_pypi import PYPI_SIMPLE_URL
 from python_inspector.utils_pypi import Environment
+from python_inspector.utils_pypi import valid_python_versions
 
 
 class Resolution(NamedTuple):
@@ -67,8 +69,8 @@ def resolve_dependencies(
     requirement_files=tuple(),
     setup_py_file=None,
     specifiers=tuple(),
-    python_version=DEFAULT_PYTHON_VERSION,
-    operating_system="linux",
+    python_version=None,
+    operating_system=None,
     index_urls=tuple([PYPI_SIMPLE_URL]),
     pdt_output=None,
     netrc_file=None,
@@ -93,6 +95,22 @@ def resolve_dependencies(
     to PyPI.org
     """
 
+    if not operating_system:
+        raise Exception(f"No operating system provided.")
+    if operating_system not in PLATFORMS_BY_OS:
+        raise ValueError(
+            f"Invalid operating system: {operating_system}. "
+            f"Must be one of: {', '.join(PLATFORMS_BY_OS.keys())}"
+        )
+
+    if not python_version:
+        raise Exception(f"No python version provided.")
+    if python_version not in valid_python_versions:
+        raise ValueError(
+            f"Invalid python version: {python_version}. "
+            f"Must be one of: {', '.join(valid_python_versions)}"
+        )
+
     if verbose:
         printer("Resolving dependencies...")
 
@@ -110,9 +128,9 @@ def resolve_dependencies(
     if netrc_file:
         if verbose:
             printer(f"Using netrc file {netrc_file}")
-        netrc = Netrc(file=netrc_file)
+        parsed_netrc = netrc(netrc_file)
     else:
-        netrc = None
+        parsed_netrc = None
 
     # TODO: deduplicate me
     direct_dependencies = []
@@ -187,7 +205,7 @@ def resolve_dependencies(
     if not direct_dependencies:
         return Resolution(
             packages=[],
-            resolution={},
+            resolution=[],
             files=files,
         )
 
@@ -215,8 +233,8 @@ def resolve_dependencies(
                 repos.append(existing)
             else:
                 credentials = None
-                if netrc:
-                    login, password = utils.get_netrc_auth(index_url, netrc)
+                if parsed_netrc:
+                    login, password = utils.get_netrc_auth(index_url, parsed_netrc)
                     credentials = (
                         dict(login=login, password=password) if login and password else None
                     )
